@@ -276,6 +276,18 @@ class Request:
             # if key == 'callback' and value is None:
             #     request_dict[key] = 'parse'
 
+            # 判断是否含有 request
+            if isinstance(value, Request):
+                continue
+            elif isinstance(value, dict):
+                del_k = []
+                for k, v in value.items():
+                    if isinstance(v, Request):
+                        del_k.append(k)
+
+                for k in del_k:
+                    del value[k]
+
             # _打头的名字 和 无值的忽略
             if key.startswith('_') or not value:
                 continue
